#[non_exhaustive]pub enum LevelSourceKind {
Physical,
SyntheticDownsample,
}Expand description
Whether a pyramid level is backed by source pixels or generated by the reader.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Physical
The level has pixel data backed directly by the source dataset.
SyntheticDownsample
The level is synthesized by downsampling another level.