#[non_exhaustive]pub enum TileOutputPreference {
Cpu {
backend: OutputBackendRequest,
},
PreferDevice {
backend: OutputBackendRequest,
context: DeviceOutputContext,
},
RequireDevice {
backend: OutputBackendRequest,
context: DeviceOutputContext,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
Sourceimpl TileOutputPreference
impl TileOutputPreference
Sourcepub fn cpu() -> Self
pub fn cpu() -> Self
CPU-resident output; codec picks cheapest backend that returns host pixels.
Sourcepub fn prefer_device_auto() -> Self
pub fn prefer_device_auto() -> Self
Prefer device output, fall back to CPU silently.
Sourcepub fn require_device_auto() -> Self
pub fn require_device_auto() -> Self
Require device output, letting the codec choose the device backend.
Sourcepub fn prefer_device_auto_with_compressed_decode() -> Self
pub fn prefer_device_auto_with_compressed_decode() -> Self
Prefer device output and explicitly allow compressed source tile device decode.
Sourcepub fn require_device_auto_with_compressed_decode() -> Self
pub fn require_device_auto_with_compressed_decode() -> Self
Require device output and explicitly allow compressed source tile device decode.
pub fn backend(&self) -> OutputBackendRequest
pub fn requires_device(&self) -> bool
pub fn prefers_device(&self) -> bool
pub fn compressed_device_decode_enabled(&self) -> bool
pub fn adaptive_decode_route_enabled(&self) -> bool
pub fn without_adaptive_decode_route(self) -> Self