#[non_exhaustive]pub struct ProbeResult {
pub detected: bool,
pub vendor: String,
pub confidence: ProbeConfidence,
}Expand description
Result from a cheap file-format probe.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.detected: boolvendor: Stringconfidence: ProbeConfidenceImplementations
Sourceimpl ProbeResult
impl ProbeResult
Sourcepub fn detected(vendor: impl Into<String>, confidence: ProbeConfidence) -> Self
pub fn detected(vendor: impl Into<String>, confidence: ProbeConfidence) -> Self
Creates a positive probe result for a detected vendor.
Sourcepub fn not_detected(vendor: impl Into<String>) -> Self
pub fn not_detected(vendor: impl Into<String>) -> Self
Creates a negative probe result for a vendor that did not match.
The registry ignores confidence when detected is false.