#[non_exhaustive]pub struct TileRequest {
pub scene: SceneId,
pub series: SeriesId,
pub level: LevelIdx,
pub plane: PlaneIdx,
pub col: i64,
pub row: i64,
}Expand description
A single-tile request — the backend primitive.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.scene: SceneIdseries: SeriesIdlevel: LevelIdxplane: PlaneIdxcol: i64row: i64Implementations
Sourceimpl TileRequest
impl TileRequest
Sourcepub fn new(
scene: impl Into<SceneId>,
series: impl Into<SeriesId>,
level: impl Into<LevelIdx>,
col: i64,
row: i64,
) -> Self
pub fn new( scene: impl Into<SceneId>, series: impl Into<SeriesId>, level: impl Into<LevelIdx>, col: i64, row: i64, ) -> Self
Build a source tile request for the default z/c/t plane.
Sourcepub fn builder(
scene: impl Into<SceneId>,
series: impl Into<SeriesId>,
level: impl Into<LevelIdx>,
) -> TileRequestBuilder
pub fn builder( scene: impl Into<SceneId>, series: impl Into<SeriesId>, level: impl Into<LevelIdx>, ) -> TileRequestBuilder
Start a named-field builder for a source tile request.
Sourcepub fn with_plane(self, plane: impl Into<PlaneIdx>) -> Self
pub fn with_plane(self, plane: impl Into<PlaneIdx>) -> Self
Return a copy of this request targeting a specific z/c/t plane.